@@ -9,7 +9,7 @@ from typing import Callable, Dict, List, Optional, Tuple
 
 from plugin import Plugin, PluginLifecycleListener, PluginManager, PluginSpec
 from readerwriterlock import rwlock
-from requests.models import Request
+from werkzeug import Request
 
 from localstack import config
 from localstack.config import ServiceProviderConfig
@@ -133,11 +133,26 @@ class ServiceLifecycleHook:
         pass
 
 
-class StateLifecycle:
-    def retrieve_state(self):
-        pass
+class BackendStateLifecycle(abc.ABC):
+    """
+    Interface that supports the retrieval, injection and restore of the backend for services.
+    """
 
-    def inject_state(self, state):
+    @abc.abstractmethod
+    def retrieve_state(self, **kwargs):
+        """Retrieves the backend of a service"""
+
+    @abc.abstractmethod
+    def inject_state(self, **kwargs):
+        """Injects a backend for a service"""
+
+    @abc.abstractmethod
+    def reset_state(self):
+        """Resets a backend for a service"""
+
+    @abc.abstractmethod
+    def on_after_reset(self):
+        """Performed after the reset of a service"""
         pass
 
 
@@ -151,7 +166,7 @@ class Service:
         active=False,
         stop=None,
         lifecycle_hook: ServiceLifecycleHook = None,
-        state_lifecycle: StateLifecycle = None,
+        backend_state_lifecycle: BackendStateLifecycle = None,
     ):
         self.plugin_name = name
         self.start_function = start
@@ -160,7 +175,7 @@ class Service:
         self.default_active = active
         self.stop_function = stop
         self.lifecycle_hook = lifecycle_hook or ServiceLifecycleHook()
-        self.state_lifecycle = state_lifecycle
+        self.backend_state_lifecycle = backend_state_lifecycle
         call_safe(self.lifecycle_hook.on_after_init)
 
     def start(self, asynchronous):
